'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = webseismoTracker;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _taReactTrackingpixel = require('ta-react-trackingpixel');

var _taReactTrackingpixel2 = _interopRequireDefault(_taReactTrackingpixel);

var _jsToolbox = require('@ta-interaktiv/js-toolbox');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Activates a call to a tracking pixel; based on the current content width
 * it will call a different URL.
 *
 * @param {object} props
 * @param {string} props.url_webapp Basic tracking URL, used for mobile devices.
 * @param {string} props.url_tablet Tracking URL for tablet-sized devices.
 * @param {string} props.url_desktop Tracking URL for desktop-sized devices.
 * @returns {XML} A TrackingPixel react element.
 */
function webseismoTracker(props) {

  // Die if we don't have an URL to track with
  if (!('url_webapp' in props) || props.url_webapp === '') {
    return null;
  }

  // Default tracking URL – mobile version
  var url = props.url_webapp;

  if (_jsToolbox.browserCheck.isTablet) {
    url = props.url_tablet;
  }

  if (_jsToolbox.browserCheck.isDesktop) {
    url = props.url_desktop;
  }

  return _react2.default.createElement(_taReactTrackingpixel2.default, { url: url + '?nocache=' + Math.random() * 100000 });
} /**
   * Tracker component to render an invisible pixel image
   * that tracks the hits on the page on the Webseismo screen.
   * @module WebseismoTracker
   * @version 2.0
   */

webseismoTracker.propTypes = {
  url_desktop: _react2.default.PropTypes.string.isRequired,
  url_webapp: _react2.default.PropTypes.string.isRequired,
  url_tablet: _react2.default.PropTypes.string.isRequired
};