/**
 * Tracker component to render an invisible pixel image
 * that tracks the hits on the page on the Webseismo screen.
 * @module WebseismoTracker
 * @version 2.0
 */

import React from 'react';
import TrackingPixel from 'ta-react-trackingpixel';
import { browserCheck } from '@ta-interaktiv/js-toolbox'

/**
 * Activates a call to a tracking pixel; based on the current content width
 * it will call a different URL.
 *
 * @param {object} props
 * @param {string} props.url_webapp Basic tracking URL, used for mobile devices.
 * @param {string} props.url_tablet Tracking URL for tablet-sized devices.
 * @param {string} props.url_desktop Tracking URL for desktop-sized devices.
 * @returns {XML} A TrackingPixel react element.
 */
export default function webseismoTracker(props) {

  // Die if we don't have an URL to track with
  if (!('url_webapp' in props) || props.url_webapp === '') {
    return null;
  }

  // Default tracking URL – mobile version
  let url = props.url_webapp;

  if (browserCheck.isTablet) {
    url = props.url_tablet
  }

  if (browserCheck.isDesktop) {
    url = props.url_desktop
  }

  return <TrackingPixel url={`${url}?nocache=${Math.random() * 100000}`}/>
}

webseismoTracker.propTypes = {
  url_desktop: React.PropTypes.string.isRequired,
  url_webapp: React.PropTypes.string.isRequired,
  url_tablet: React.PropTypes.string.isRequired
};
